Installation
============

Download and install ``django-pages-cms`` using **one** of the following methods:

PIP
---

You can install the latest stable package running this command::

    $ pip install django-pages-cms

Also you can install the development version running this command::

    $ pip install -e git+http://github.com/dlancer/django-pages-cms.git#egg=pages-dev

If you use Django<1.7, you should install South==1.0.1

Setuptools
----------

You can install the latest stable package running::

    $ easy_install django-pages-cms


